"""
This module provides access to selection.

"""

import typing
import collections.abc
import typing_extensions

def load_id(id):
    """Set the selection ID.

    :param id: Number (32-bit uint).
    """
